@@ -2,7 +2,7 @@ package Atomic::Pipe;
 use strict;
 use warnings;
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use IO();
 use Fcntl();
@@ -191,8 +191,8 @@ sub eof {
     return 0 if $self->{+IN_BUFFER_SIZE};
 
     if (my $buffer = $self->{+MIXED_BUFFER}) {
-        return 0 if $buffer->{lines} || length $buffer->{lines};
-        return 0 if $buffer->{burst} || length $buffer->{burst};
+        return 0 if $buffer->{lines} || defined($buffer->{lines}) && length($buffer->{lines});
+        return 0 if $buffer->{burst} || defined($buffer->{lines}) && length($buffer->{burst});
     }
 
     return 1;
